package data_manage

import (
	"eta/eta_hub/utils"
	"fmt"
	"github.com/beego/beego/v2/client/orm"
	"strings"
)

var (
	EdbSourceIdMap map[int]*EdbSource // 指标来源ID映射
)

// EdbSource 指标来源表
type EdbSource struct {
	EdbSourceId      int    `orm:"column(edb_source_id);pk"`
	SourceName       string `description:"指标来源名称"`
	TableName        string `description:"数据表名"`
	EdbAddMethod     string `description:"指标新增接口"`
	EdbRefreshMethod string `description:"指标刷新接口"`
	IsBase           int    `description:"是否为基础指标: 0-否; 1-是"`
	FromBridge       int    `description:"是否来源于桥接服务: 0-否; 1-是"`
	BridgeFlag       string `description:"桥接服务对象标识"`
	SourceExtend     string `description:"扩展字段做查询用"`
	EdbCodeRequired  int    `description:"指标编码是否必填: 0-否; 1-是"`
}

// GetEdbSourceItemsByCondition 获取指标来源列表
func GetEdbSourceItemsByCondition(condition string, pars []interface{}, fieldArr []string, orderRule string) (items []*EdbSource, err error) {
	o := orm.NewOrmUsingDB("data")
	fields := strings.Join(fieldArr, ",")
	if len(fieldArr) == 0 {
		fields = `*`
	}
	order := `ORDER BY edb_source_id ASC`
	if orderRule != "" {
		order = ` ORDER BY ` + orderRule
	}
	sql := fmt.Sprintf(`SELECT %s FROM edb_source WHERE 1=1 %s %s`, fields, condition, order)
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

// GetEdbSourceItemByCondition 获取指标来源
func GetEdbSourceItemByCondition(condition string, pars []interface{}) (item *EdbSource, err error) {
	o := orm.NewOrmUsingDB("data")
	sql := fmt.Sprintf(`SELECT * FROM edb_source WHERE 1=1 %s`, condition)
	err = o.Raw(sql, pars).QueryRow(&item)
	return
}

// EdbSourceItem 指标来源信息
type EdbSourceItem struct {
	SourceId   int    `description:"指标来源ID"`
	SourceName string `description:"指标来源名称"`
	//TableName  string `description:"数据表名"`
	SourceType int `description:"来源类型: 1-基础指标; 2-计算指标"`
}

// FormatEdbSource2Item 格式化指标来源信息
func FormatEdbSource2Item(origin *EdbSource) (item *EdbSourceItem) {
	if origin == nil {
		return
	}
	item = new(EdbSourceItem)
	item.SourceId = origin.EdbSourceId
	item.SourceName = origin.SourceName
	//item.TableName = origin.TableName
	item.SourceType = origin.IsBase
	return
}

// InitEdbSource 初始化时加载指标来源
func InitEdbSource() {
	EdbSourceIdMap = make(map[int]*EdbSource)
	sources, e := GetEdbSourceItemsByCondition(``, make([]interface{}, 0), []string{}, "")
	if e != nil {
		utils.FileLog.Info("init source table err: %s", e.Error())
		return
	}
	for _, v := range sources {
		EdbSourceIdMap[v.EdbSourceId] = v
	}
}
