// @Author gmy 2024/9/19 14:53:00
package document_manage_model

import (
	"github.com/beego/beego/v2/client/orm"
	"github.com/rdlucklib/rdluck_tools/paging"
)

type OutsideReport struct {
	OutsideReportId  int    `orm:"column(outside_report_id);pk" description:"外部报告ID"`
	Source           int    `orm:"column(source)" description:"来源，1：ETA系统录入；2：API接口录入；3：邮件监听录入"`
	Title            string `orm:"column(title)" description:"报告标题"`
	Abstract         string `orm:"column(abstract)" description:"摘要"`
	ClassifyId       int    `orm:"column(classify_id)" description:"所属分类id"`
	ClassifyName     string `orm:"column(classify_name)" description:"所属分类名称（整个分类链条）"`
	Content          string `orm:"column(content)" description:"报告富文本内容"`
	SysUserId        int    `orm:"column(sys_user_id)" description:"创建人id"`
	SysUserName      string `orm:"column(sys_user_name)" description:"创建人姓名"`
	EmailMessageUid  int    `orm:"column(email_message_uid)" description:"该邮件在邮箱中的唯一id"`
	ReportUpdateTime string `orm:"column(report_update_time)" description:"报告更新时间，如果来源于邮件，那么取邮件的收件时间"`
	ModifyTime       string `orm:"column(modify_time)" description:"最近一次修改时间"`
	CreateTime       string `orm:"column(create_time)" description:"创建时间"`
	ReportCode       string `orm:"column(report_code)" description:"报告唯一编码"`
}

type OutsideReportPage struct {
	List   []OutsideReport    `description:"报告列表"`
	Paging *paging.PagingItem `description:"分页数据"`
}

type OutsideReportBO struct {
	OutsideReportId int    `orm:"column(outside_report_id);pk" description:"外部报告ID"`
	Source          int    `orm:"column(source)" description:"来源，1：ETA系统录入；2：API接口录入；3：邮件监听录入"`
	Title           string `orm:"column(title)" description:"报告标题"`
	Abstract        string `orm:"column(abstract)" description:"摘要"`
	ClassifyId      int    `orm:"column(classify_id)" description:"所属分类id"`
	ClassifyName    string `orm:"column(classify_name)" description:"所属分类名称（整个分类链条）"`
	Content         string `orm:"column(content)" description:"报告富文本内容"`
	SysUserId       int    `orm:"column(sys_user_id)" description:"创建人id"`
	SysUserName     string `orm:"column(sys_user_name)" description:"创建人姓名"`
	ReportCode      string `orm:"column(report_code)" description:"报告唯一编码"`
	AuthCode        string `orm:"column(auth_code)" description:"报告权限编码"`
	UserName        string `description:"用户名称"`
	AttachmentList  []*OutsideReportAttachment
}

// 在 init 函数中注册模型
func init() {
	orm.RegisterModel(new(OutsideReport))
}

// SaveOutsideReport 保存报告
func SaveOutsideReport(outsideReport OutsideReport) (id int64, err error) {
	o := orm.NewOrmUsingDB("rddp")
	id, err = o.Insert(&outsideReport)
	return
}
