package system

import (
	"eta/eta_hub/utils"
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type Admin struct {
	AdminId                   int    `orm:"column(admin_id);pk" description:"系统用户id"`
	AdminName                 string `description:"系统用户名称"`
	AdminAvatar               string `description:"用户头像"`
	RealName                  string `description:"系统用户姓名"`
	Password                  string `json:"-"`
	LastUpdatedPasswordTime   string `json:"-"`
	Enabled                   int
	Email                     string `description:"系统用户邮箱"`
	LastLoginTime             string
	CreatedTime               time.Time
	LastUpdatedTime           string
	Role                      string    `description:"系统用户角色"`
	Mobile                    string    `description:"手机号"`
	RoleType                  int       `description:"角色类型:1需要录入指标,0:不需要"`
	RoleId                    int       `description:"角色ID"`
	RoleName                  string    `description:"角色名称"`
	RoleTypeCode              string    `description:"角色类型编码"`
	DepartmentId              int       `description:"部门id"`
	DepartmentName            string    `description:"部门名称"`
	GroupId                   int       `description:"分组id"`
	GroupName                 string    `description:"分组名称"`
	Authority                 int       `description:"管理权限，0：无，1：部门负责人，2：小组负责人,或者ficc销售主管，3：超级管理员，4:ficc销售组长"`
	Position                  string    `description:"职位"`
	DisableTime               time.Time `description:"禁用时间"`
	ChartPermission           int8      `description:"图表权限id"`
	OpenId                    string    `description:"弘则部门公众号的openid"`
	UnionId                   string    `description:"微信公众平台唯一标识"`
	EdbPermission             int8      `description:"指标库操作权限，0：只能操作 自己的，1：所有指标可操作"`
	MysteelChemicalPermission int8      `description:"钢联化工指标操作权限，0：只能操作 自己的，1：所有指标可操作"`
	PredictEdbPermission      int8      `description:"预测指标库操作权限，0：只能操作 自己的，1：所有预测指标可操作"`
	Province                  string    `description:"省"`
	ProvinceCode              string    `description:"省编码"`
	City                      string    `description:"市"`
	CityCode                  string    `description:"市编码"`
	EmployeeId                string    `description:"员工工号(钉钉/每刻报销)"`
	TelAreaCode               string    `description:"手机区号"`
}

type AdminItem struct {
	AdminId                   int    `orm:"column(admin_id);pk" description:"系统用户id"`
	AdminName                 string `description:"系统用户名称"`
	AdminAvatar               string `json:"-" description:"用户头像"`
	RealName                  string `description:"系统用户姓名"`
	Password                  string `json:"-"`
	LastUpdatedPasswordTime   string `json:"-"`
	Enabled                   int
	Email                     string `description:"系统用户邮箱"`
	LastLoginTime             string `json:"-"`
	CreatedTime               string `json:"-"`
	LastUpdatedTime           string `json:"-"`
	Role                      string `description:"系统用户角色"`
	Mobile                    string `description:"手机号"`
	RoleType                  int    `json:"-" description:"角色类型:1需要录入指标,0:不需要"`
	RoleId                    int    `json:"-" description:"角色ID"`
	RoleName                  string `json:"-" description:"角色名称"`
	RoleTypeCode              string `json:"-" description:"角色类型编码"`
	DepartmentId              int    `description:"部门id"`
	DepartmentName            string `description:"部门名称"`
	GroupId                   int    `description:"分组id"`
	GroupName                 string `description:"分组名称"`
	Authority                 int    `json:"-" description:"管理权限，0：无，1：部门负责人，2：小组负责人,或者ficc销售主管，3：超级管理员，4:ficc销售组长"`
	Position                  string `description:"职位"`
	DisableTime               string `json:"-" description:"禁用时间"`
	ChartPermission           int8   `json:"-" description:"图表权限id"`
	OpenId                    string `json:"-" description:"弘则部门公众号的openid"`
	UnionId                   string `json:"-" description:"微信公众平台唯一标识"`
	EdbPermission             int8   `json:"-" description:"指标库操作权限，0：只能操作 自己的，1：所有指标可操作"`
	MysteelChemicalPermission int8   `json:"-" description:"钢联化工指标操作权限，0：只能操作 自己的，1：所有指标可操作"`
	PredictEdbPermission      int8   `json:"-" description:"预测指标库操作权限，0：只能操作 自己的，1：所有预测指标可操作"`
	Province                  string `json:"-" description:"省"`
	ProvinceCode              string `json:"-" description:"省编码"`
	City                      string `json:"-" description:"市"`
	CityCode                  string `json:"-" description:"市编码"`
	EmployeeId                string `json:"-" description:"员工工号(钉钉/每刻报销)"`
	TelAreaCode               string `description:"手机区号"`
}

// GetSysUserByAdminName 账号获取用户
func GetSysUserByAdminName(adminName string) (item *AdminItem, err error) {
	o := orm.NewOrm()
	sql := `SELECT
				a.*, b.role_type_code
			FROM
				admin AS a
			INNER JOIN sys_role AS b ON a.role_id = b.role_id
			WHERE
				a.admin_name = ?
			LIMIT 1`
	err = o.Raw(sql, adminName).QueryRow(&item)
	return
}

// GetUserByAdminName 根据系统用户名获取用户信息
func GetUserByAdminName(adminName string) (item *AdminItem, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM admin WHERE admin_name = ? LIMIT 1`
	err = o.Raw(sql, adminName).QueryRow(&item)

	if err != nil && err.Error() == utils.ErrNoRow() {
		return nil, nil
	}

	return item, err
}

type UserCheckResp struct {
	IsUser    bool
	AdminInfo *AdminItem
}
